==> aaa_elflibs-10.1.0-i486-1.tgz: install/doinst.sh <==
( cd lib ; rm -rf libbz2.so.1 )
( cd lib ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd lib ; rm -rf libncurses.so.5 )
( cd lib ; ln -sf libncurses.so.5.4 libncurses.so.5 )
( cd lib ; rm -rf libgpm.so.1 )
( cd lib ; ln -sf libgpm.so.1.18.0 libgpm.so.1 )
( cd lib ; rm -rf libdb.so.2 )
( cd lib ; ln -sf libdb1.so.2.1.3 libdb.so.2 )
( cd lib ; rm -rf libdb.so.3 )
( cd lib ; ln -sf libdb2.so.3 libdb.so.3 )
( cd lib ; rm -rf libbz2.so.1.0 )
( cd lib ; ln -sf libbz2.so.1.0.2 libbz2.so.1.0 )
( cd lib ; rm -rf libncursesw.so.5 )
( cd lib ; ln -sf libncursesw.so.5.4 libncursesw.so.5 )
( cd lib ; rm -rf libtermcap.so.2 )
( cd lib ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd usr/lib ; rm -rf libreadline.so.4 )
( cd usr/lib ; ln -sf libreadline.so.4.3 libreadline.so.4 )
( cd usr/lib ; rm -rf libexpat.so.0 )
( cd usr/lib ; ln -sf libexpat.so.0.5.0 libexpat.so.0 )
( cd usr/lib ; rm -rf libformw.so.5 )
( cd usr/lib ; ln -sf libformw.so.5.4 libformw.so.5 )
( cd usr/lib ; rm -rf libjpeg.so.62 )
( cd usr/lib ; ln -sf libjpeg.so.62.0.0 libjpeg.so.62 )
( cd usr/lib ; rm -rf libmp.so.3 )
( cd usr/lib ; ln -sf libmp.so.3.1.7 libmp.so.3 )
( cd usr/lib ; rm -rf libvga.so.1 )
( cd usr/lib ; ln -sf libvga.so.1.4.3 libvga.so.1 )
( cd usr/lib ; rm -rf libz.so.1 )
( cd usr/lib ; ln -sf libz.so.1.2.1.1 libz.so.1 )
( cd usr/lib ; rm -rf libgmp.so.3 )
( cd usr/lib ; ln -sf libgmp.so.3.3.3 libgmp.so.3 )
( cd usr/lib ; rm -rf libhistory.so.4 )
( cd usr/lib ; ln -sf libhistory.so.4.3 libhistory.so.4 )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.600.1 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libvgagl.so.1 )
( cd usr/lib ; ln -sf libvgagl.so.1.4.3 libvgagl.so.1 )
( cd usr/lib ; rm -rf libslang.so.1 )
( cd usr/lib ; ln -sf libslang.so.1.4.9 libslang.so.1 )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.600.1 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libpcre.so.0 )
( cd usr/lib ; ln -sf libpcre.so.0.0.1 libpcre.so.0 )
( cd usr/lib ; rm -rf libmenu.so.5 )
( cd usr/lib ; ln -sf libmenu.so.5.4 libmenu.so.5 )
( cd usr/lib ; rm -rf libusb-0.1.so.4 )
( cd usr/lib ; ln -sf libusb-0.1.so.4.4.0 libusb-0.1.so.4 )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.600.1 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libpopt.so.0 )
( cd usr/lib ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd usr/lib ; rm -rf libtiff.so.3 )
( cd usr/lib ; ln -sf libtiff.so.3.6.1 libtiff.so.3 )
( cd usr/lib ; rm -rf libgdbm.so.2 )
( cd usr/lib ; ln -sf libgdbm.so.2.0.0 libgdbm.so.2 )
( cd usr/lib ; rm -rf libgdbm.so.3 )
( cd usr/lib ; ln -sf libgdbm.so.3.0.0 libgdbm.so.3 )
( cd usr/lib ; rm -rf libgmpxx.so.3 )
( cd usr/lib ; ln -sf libgmpxx.so.3.0.5 libgmpxx.so.3 )
( cd usr/lib ; rm -rf libpcreposix.so.0 )
( cd usr/lib ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so.0 )
( cd usr/lib ; rm -rf libasound.so.2 )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.3.1.2.8 libpng.so.3 )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so.0.1.2.8 libpng12.so.0 )
( cd usr/lib ; rm -rf libpanelw.so.5 )
( cd usr/lib ; ln -sf libpanelw.so.5.4 libpanelw.so.5 )
( cd usr/lib ; rm -rf libmenuw.so.5 )
( cd usr/lib ; ln -sf libmenuw.so.5.4 libmenuw.so.5 )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.600.1 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libfreetype.so.6 )
( cd usr/lib ; ln -sf libfreetype.so.6.3.7 libfreetype.so.6 )
( cd usr/lib ; rm -rf libcurl.so.2 )
( cd usr/lib ; ln -sf libcurl.so.2.0.2 libcurl.so.2 )
( cd usr/lib ; rm -rf libcurl.so.3 )
( cd usr/lib ; ln -sf libcurl.so.3.0.0 libcurl.so.3 )
( cd usr/lib ; rm -rf libpanel.so.5 )
( cd usr/lib ; ln -sf libpanel.so.5.4 libpanel.so.5 )
( cd usr/lib ; rm -rf libform.so.5 )
( cd usr/lib ; ln -sf libform.so.5.4 libform.so.5 )

==> aaa_elflibs-10.2.0-i486-3.tgz: install/doinst.sh <==
( cd lib ; rm -rf libbz2.so.1 )
( cd lib ; ln -sf libbz2.so.1.0.3 libbz2.so.1 )
( cd lib ; rm -rf libncurses.so.5 )
( cd lib ; ln -sf libncurses.so.5.4 libncurses.so.5 )
( cd lib ; rm -rf libgpm.so.1 )
( cd lib ; ln -sf libgpm.so.1.18.0 libgpm.so.1 )
( cd lib ; rm -rf libdb.so.2 )
( cd lib ; ln -sf libdb1.so.2.1.3 libdb.so.2 )
( cd lib ; rm -rf libdb.so.3 )
( cd lib ; ln -sf libdb2.so.3 libdb.so.3 )
( cd lib ; rm -rf libbz2.so.1.0 )
( cd lib ; ln -sf libbz2.so.1.0.3 libbz2.so.1.0 )
( cd lib ; rm -rf libncursesw.so.5 )
( cd lib ; ln -sf libncursesw.so.5.4 libncursesw.so.5 )
( cd lib ; rm -rf libtermcap.so.2 )
( cd lib ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd usr/lib ; rm -rf libreadline.so.4 )
( cd usr/lib ; ln -sf libreadline.so.4.3 libreadline.so.4 )
( cd usr/lib ; rm -rf libexpat.so.0 )
( cd usr/lib ; ln -sf libexpat.so.0.5.0 libexpat.so.0 )
( cd usr/lib ; rm -rf libformw.so.5 )
( cd usr/lib ; ln -sf libformw.so.5.4 libformw.so.5 )
( cd usr/lib ; rm -rf libjpeg.so.62 )
( cd usr/lib ; ln -sf libjpeg.so.62.0.0 libjpeg.so.62 )
( cd usr/lib ; rm -rf libmp.so.3 )
( cd usr/lib ; ln -sf libmp.so.3.1.7 libmp.so.3 )
( cd usr/lib ; rm -rf libvga.so.1 )
( cd usr/lib ; ln -sf libvga.so.1.4.3 libvga.so.1 )
( cd usr/lib ; rm -rf libz.so.1 )
( cd usr/lib ; ln -sf libz.so.1.2.3 libz.so.1 )
( cd usr/lib ; rm -rf libgmp.so.3 )
( cd usr/lib ; ln -sf libgmp.so.3.3.3 libgmp.so.3 )
( cd usr/lib ; rm -rf libhistory.so.4 )
( cd usr/lib ; ln -sf libhistory.so.4.3 libhistory.so.4 )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.600.6 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libvgagl.so.1 )
( cd usr/lib ; ln -sf libvgagl.so.1.4.3 libvgagl.so.1 )
( cd usr/lib ; rm -rf libslang.so.1 )
( cd usr/lib ; ln -sf libslang.so.1.4.9 libslang.so.1 )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.600.6 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libpcre.so.0 )
( cd usr/lib ; ln -sf libpcre.so.0.0.1 libpcre.so.0 )
( cd usr/lib ; rm -rf libmenu.so.5 )
( cd usr/lib ; ln -sf libmenu.so.5.4 libmenu.so.5 )
( cd usr/lib ; rm -rf libusb-0.1.so.4 )
( cd usr/lib ; ln -sf libusb-0.1.so.4.4.0 libusb-0.1.so.4 )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.600.6 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libpopt.so.0 )
( cd usr/lib ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd usr/lib ; rm -rf libtiff.so.3 )
( cd usr/lib ; ln -sf libtiff.so.3.7.3 libtiff.so.3 )
( cd usr/lib ; rm -rf libgdbm.so.2 )
( cd usr/lib ; ln -sf libgdbm.so.2.0.0 libgdbm.so.2 )
( cd usr/lib ; rm -rf libgdbm.so.3 )
( cd usr/lib ; ln -sf libgdbm.so.3.0.0 libgdbm.so.3 )
( cd usr/lib ; rm -rf libgmpxx.so.3 )
( cd usr/lib ; ln -sf libgmpxx.so.3.0.5 libgmpxx.so.3 )
( cd usr/lib ; rm -rf libpcreposix.so.0 )
( cd usr/lib ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so.0 )
( cd usr/lib ; rm -rf libasound.so.2 )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.3.1.2.8 libpng.so.3 )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so.0.1.2.8 libpng12.so.0 )
( cd usr/lib ; rm -rf libpanelw.so.5 )
( cd usr/lib ; ln -sf libpanelw.so.5.4 libpanelw.so.5 )
( cd usr/lib ; rm -rf libmenuw.so.5 )
( cd usr/lib ; ln -sf libmenuw.so.5.4 libmenuw.so.5 )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.600.6 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libfreetype.so.6 )
( cd usr/lib ; ln -sf libfreetype.so.6.3.7 libfreetype.so.6 )
( cd usr/lib ; rm -rf libcurl.so.2 )
( cd usr/lib ; ln -sf libcurl.so.2.0.2 libcurl.so.2 )
( cd usr/lib ; rm -rf libcurl.so.3 )
( cd usr/lib ; ln -sf libcurl.so.3.0.0 libcurl.so.3 )
( cd usr/lib ; rm -rf libpanel.so.5 )
( cd usr/lib ; ln -sf libpanel.so.5.4 libpanel.so.5 )
( cd usr/lib ; rm -rf libform.so.5 )
( cd usr/lib ; ln -sf libform.so.5.4 libform.so.5 )
